#!/bin/sh
ifconfig wlan0 0.0.0.0
ifconfig wlan0 down
sleep 1
stop wlancond
/usr/bin/advifsw/exec.sh ./post-down